==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_seapath.lua <==
function E0090()
    MNA()CMU("XXXX")FAI(0)
end
function E0091()
    MNA()CMU("XXXX")FAI(1)
end
function E0092()
    MNA()CMU("XXXX")FAI(2)
end
function E0093()
    MNA()CMU("XXXX")FAI(3)
end
function E0094()
    MNA()CMU("XXXX")FAI(4)
end

function CannotGoOut()
    PRI()
    MS4("\n不能丢下大鱼！")NOD()
end

function CannotEscape()
    PRI()
    TUR()MS4("\n不能逃跑！")NOD()
end

function Door_GoSeaCave()
    if(FLJ("InBossFight")) then
        CannotEscape()
    elseif(FLJ("CannotGoOut")) then
        CannotGoOut()
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoSeaCave",0,1)FAO(3)TRA("CS_seacave","E0091",36,13)
    end
end

function Door_GoPuuRestaurant()
    if(FLJ("InBossFight")) then
        CannotEscape()
    elseif(FLJ("CannotGoOut")) then
        CannotGoOut()
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoPuuRestaurant",0,1)FAO(1)TRA("CS_puu_restaurant","E0093",4,12)
    end
end


function SomeWhereTalking()
    PRI()
    POS(true)
    DNP("SomeWhereTalking")FLP("SomeWhereTalking")
    MS4("\n你似乎一瞬间听到了什么声音...")NOD()CLO()
    FAO(2)TRA("CS_puu_restaurant","SomeWhereTalking",4,12)
end

--龙鱼醒了
function ArowanaWake()
    KEY()
    CNP("Kanpa1","CS_mychar_kanpa_animate",0,0)
    CNP("Arowana1","CS_arowana_animate",0,0)
    ANP("Arowana1","fallen",0)
    --间八开始推动
    ANP("Kanpa1","start_push",0)
    HMC()
    FAI(1)
    WAI(192)
    --鱼醒了
    ANP("Arowana1","wake",0)
    WAI(32)
    MS3("好痛啊！不要拖着我了！")
    CAT("\n我的皮都快掉了")WAI(32)CLO()
    ANP("Kanpa1","start_push",0)
    WAI(32)
    ANP("Kanpa1","end_push",0)
    WAI(32)
    ANP("Arowana1","makeSmoke",1)
    ANP("Arowana1","normal",1)
    ANP("Kanpa1","MYB",0)
    WAI(32)
    MS3("你是谁啊！")NOD()
    MS3("\n为什么要把我从水池里带出来？")NOD()
    WAI(8)CAT("\n.")WAI(8)CAT(".")WAI(8)CAT(".")WAI(8)CAT(".")WAI(8)CAT(".")WAI(8)CAT(".")CLR()
    ANP("Arowana1","jump",1)
    ANP("Arowana1","angry",1)
    ANP("Kanpa1","MYB",0)
    CAT("什么？！")NOD()CAT("要把我拿去喂猫？")NOD()
    CAT("\n我可是这里独一无二")
    CAT("\n贵重到不能再贵重的龙鱼啊！")NOD()CLR()
    CAT("可恶啊－！")NOD()
    CAT("\n我要杀了你！！")NOD()CLO()
    SKP("QuackBoss")
    ANP("Kanpa1","MYB",0)
    CMU("CS_Gravity")
    WAI(32)
    CNP("ArowanaBoss","CS_boss_arowana",0,1)
    MNP("ArowanaBoss","Arowana1")
    BSL("ArowanaBoss")
    FLP("InBossFight")
    DNP("Arowana1")
    MOV("Kanpa1")
    DNP("Kanpa1")
    SLR(0)
    SMC()
end

function QuackBoss()
    PRI()
    CMU("CS_Gravity")
    CNP("ArowanaBoss","CS_boss_arowana",0,1)
    MNP("ArowanaBoss",18,10,1)
    ANP("ArowanaBoss",0,1)
    BSL("ArowanaBoss")
    FLP("InBossFight")
    MOV(25,10)
    SLR(0)
    SMC()
    FAI(1)
end

function ArowanaBoss()
    PRI()
    FLS("InBossFight")
    CMU("XXXX")
    MS3("我输了...")NOD()CLR()CLO()
    ANP("ArowanaBoss","set_player_type")--改成玩家类型防止掉下去
    KEY()
    WAI(80)
    CMU("CS_Fanfale3")
    MSG("\n龙鱼 被击败了！")WAI(140)NOD()
    FLP("CannotGoOut")
    FLP("DefeatedArowana")
    SKS("QuackBoss")
    CMU("XXXX")
    --替换实体
    CNP("ArowanaBoss","GetArowana")
end

function GetArowana()
    PRI()
    GIT("Arowana")ITP("Arowana")SOU("CS_038_get_item")
    ANP("GetArowana","hide")
    DNP("GetArowana")
    CMU("CS_Fanfale1")
    MSG("\n获得了 =龙鱼= 。")WAI(160)NOD()
    CMU("XXXX")
    FLS("CannotGoOut")
    SetSavePoint()
end

function LoadPos()
    PRI()MNA()CMU("XXXX")
    POS()
    FAI(2)
end

function SetSavePoint()
    CNP("SavePoint","CS_savepoint",0,0)
end

==> ocstore25_7_4.zip: OcStore/Prgm/data/map/CS_seapath.lua <==
function E0090()
    MNA()CMU("XXXX")FAI(0)
end
function E0091()
    MNA()CMU("XXXX")FAI(1)
end
function E0092()
    MNA()CMU("XXXX")FAI(2)
end
function E0093()
    MNA()CMU("XXXX")FAI(3)
end
function E0094()
    MNA()CMU("XXXX")FAI(4)
end

function CannotGoOut()
    PRI()
    MS4("\n不能丢下大鱼！")NOD()
end

function CannotEscape()
    PRI()
    TUR()MS4("\n不能逃跑！")NOD()
end

function Door_GoSeaCave()
    if(FLJ("InBossFight")) then
        CannotEscape()
    elseif(FLJ("CannotGoOut")) then
        CannotGoOut()
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoSeaCave",0,1)FAO(3)TRA("CS_seacave","E0091",36,13)
    end
end

function Door_GoPuuRestaurant()
    if(FLJ("InBossFight")) then
        CannotEscape()
    elseif(FLJ("CannotGoOut")) then
        CannotGoOut()
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoPuuRestaurant",0,1)FAO(1)TRA("CS_puu_restaurant","E0093",4,12)
    end
end


function SomeWhereTalking()
    PRI()
    POS(true)
    DNP("SomeWhereTalking")FLP("SomeWhereTalking")
    MS4("\n你似乎一瞬间听到了什么声音...")NOD()CLO()
    FAO(2)TRA("CS_puu_restaurant","SomeWhereTalking",4,12)
end

--龙鱼醒了
function ArowanaWake()
    KEY()
    CNP("Kanpa1","CS_mychar_kanpa_animate",0,0)
    CNP("Arowana1","CS_arowana_animate",0,0)
    ANP("Arowana1","fallen",0)
    --间八开始推动
    ANP("Kanpa1","start_push",0)
    HMC()
    FAI(1)
    WAI(192)
    --鱼醒了
    ANP("Arowana1","wake",0)
    WAI(32)
    MS3("好痛啊！不要拖着我了！")
    CAT("\n我的皮都快掉了")WAI(32)CLO()
    ANP("Kanpa1","start_push",0)
    WAI(32)
    ANP("Kanpa1","end_push",0)
    WAI(32)
    ANP("Arowana1","makeSmoke",1)
    ANP("Arowana1","normal",1)
    ANP("Kanpa1","MYB",0)
    WAI(32)
    MS3("你是谁啊！")NOD()
    MS3("\n为什么要把我从水池里带出来？")NOD()
    WAI(8)CAT("\n.")WAI(8)CAT(".")WAI(8)CAT(".")WAI(8)CAT(".")WAI(8)CAT(".")WAI(8)CAT(".")CLR()
    ANP("Arowana1","jump",1)
    ANP("Arowana1","angry",1)
    ANP("Kanpa1","MYB",0)
    CAT("什么？！")NOD()CAT("要把我拿去喂猫？")NOD()
    CAT("\n我可是这里独一无二")
    CAT("\n贵重到不能再贵重的龙鱼啊！")NOD()CLR()
    CAT("可恶啊－！")NOD()
    CAT("\n我要杀了你！！")NOD()CLO()
    SKP("QuickFishBoss")
    ANP("Kanpa1","MYB",0)
    CMU("CS_Gravity")
    WAI(32)
    CNP("ArowanaBoss","CS_boss_arowana",0,1)
    MNP("ArowanaBoss","Arowana1")
    BSL("ArowanaBoss")
    FLP("InBossFight")
    DNP("Arowana1")
    MOV("Kanpa1")
    DNP("Kanpa1")
    SLR(0)
    SMC()
end

function QuickFishBoss()
    PRI()
    CMU("CS_Gravity")
    CNP("ArowanaBoss","CS_boss_arowana",0,1)
    MNP("ArowanaBoss",18,10,1)
    ANP("ArowanaBoss",0,1)
    BSL("ArowanaBoss")
    FLP("InBossFight")
    MOV(25,10)
    SLR(0)
    SMC()
    FAI(1)
end

function ArowanaBoss()
    PRI()
    FLS("InBossFight")
    CMU("XXXX")
    MS3("\n我输了...")NOD()CLR()CLO()
    ANP("ArowanaBoss","set_player_type")--改成玩家类型防止掉下去
    KEY()
    WAI(80)
    CMU("CS_Fanfale3")
    MSG("\n龙鱼 被击败了！")WAI(140)NOD()
    FLP("CannotGoOut")
    FLP("DefeatedArowana")
    SKS("QuickFishBoss")
    CMU("XXXX")
    --替换实体
    CNP("ArowanaBoss","GetArowana")
end

function GetArowana()
    PRI()
    GIT("Arowana")ITP("Arowana")SOU("CS_038_get_item")
    ANP("GetArowana","hide")
    DNP("GetArowana")
    CMU("CS_Fanfale1")
    MSG("\n获得了 =龙鱼= 。")WAI(160)NOD()
    CMU("XXXX")
    FLS("CannotGoOut")
    SetSavePoint()
end

function LoadPos()
    PRI()MNA()CMU("XXXX")
    POS()
    FAI(2)
end

function SetSavePoint()
    CNP("SavePoint","CS_savepoint",0,0)
end
